<?php
/*
Plugin Name: DjVu-Integration
Plugin URI: http://tonydoubleu.com/djvu-integration
Description: Adds the ability to easily manage large volumes of DjVu files for the display of scanned documents.
Version: 0.1
Author: Tony Wieczorek
Author URI: http://tonydoubleu.com

    Copyright 2006  Tony Wieczorek  (email : tonyjw@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St. Fifth Floor, Boston, MA  02110-1301  USA

Version History
------------------------------------------------------------------------------
2006-06-26	0.1.1		Started project
				Decided on one-blog per djvu project scheme

*/

// TODO: We want to create a top-level option, since this blog's only function
// 	 is to display and keep track of these DjVu documents.


// Add a page to the Management Menu for DjVu project
function di_admin_menu() {
  if (function_exists('add_options_page')) {
    add_management_page('DjVu Integration Manager Options', 'DjVu', 7, __FILE__, 'di_admin_menu_page');
  }
}

// Register our new admin options menu
add_action('admin_menu', 'di_admin_menu');

// TODO: Options we want to display:
//	 + name of the DjVu project
//	 + copyright information (suggesting creative commons licensing)
//	 + activate comments on djvu pages?
//	 + layout (1-up, 2-up, and so on)
//	 + Create DjVu Pages (submit button)
// 	 + reload posts? 
//	   useful for when they add djvu pages to the project and want the navigation
//	   system to reflect that. Posts new directory of djvu files and deletes previous pages.
//	   Metadata about the djvu files are related by filename, not post id, so none of that 
//	   information is lost.


// lay out the html of the options page
function di_admin_menu_page() {
  // print out the html of the page
  if (isset($_POST['info_update'])) {
     // update the options given
     update_option("djvu_dir",$_POST['form_djvu_dir']);
     update_option("djvu_txt_dir",$_POST['form_djvu_txt_dir']);
     update_option("djvu_pdf_dir",$_POST['form_djvu_pdf_dir']);
     update_option("djvu_image_dir",$_POST['form_djvu_image_dir']);
     update_option("djvu_project_name",$_POST['form_djvu_project_name']);
    ?><div class="updated"><p><strong><?php  _e('Options saved.',
    'Localization name')
    ?></strong></p></div><?php
	} ?>
  <div class=wrap>
    <h2>Manage your DjVu collection</h2>
      <h3>Arranging your files</h3>
      Your DjVu collection could be one large document or a series of documents stored in one folder. However you choose to collect your documents, they need to be numbered in the order you want them displayed. Feel free to prefix the files with anything you want, as long as there is one set of numbers which determines the order of the files. Basically, the order they are in your folder is the order they will be displayed in. Here is an example of a naming scheme for your files:<br />
      <pre>slang-001.djvu<br />slang-002.djvu<br />...<br />slang-540.djvu<br /></pre>
  <form method="post">    
  <fieldset name="general_information">
    <legend>Project Information</legend>
    DjVu Project Name 
      <input type="text" name="form_djvu_project_name" value="<?php echo get_option("djvu_project_name");?>"><br />
  </fieldset>
  <fieldset name="djvu_dirs">
	<legend>DjVu directory information (please leave blank if no such directory)</legend>
	DjVu document directory
	     <input type="text" name="form_djvu_dir" value="<?php echo get_option("djvu_dir");?>"><br />
      	Directory of OCR text
	     <input type="text" name="form_djvu_txt_dir" value="<?php echo get_option("djvu_txt_dir");?>"><br />
      	Directory of PDFs
	     <input type="text" name="form_djvu_pdf_dir" value="<?php echo get_option("djvu_pdf_dir");?>"><br />
	Directory of images (png, jpg, gif, tiff)
 	     <input type="text" name="form_djvu_image_dir" value="<?php echo get_option("djvu_image_dir");?>">
      </fieldset>
      <fieldset name="set2">
	<legend><?php _e('Options set 2', 'Localization name') ?></legend>
	Put some more form input areas here.
      </fieldset>
  <div class="submit">
   <input type="submit" name="info_update" value="<?php
     _e('Update options', 'Localization name')
	?> »" /></div>
   </form>
 </div><?php
}

// Create a table in the database for our djvu stuff
function di_install () {
	// First, get some global variables from php
	global $table_prefix, $wpdb, $user_level;;
	$table_name = $table_prefix . "djvu_meta";
	
	// Make sure the user is allowed to do this to the db
	if ($user_level < 8) { return; }
	$wpdb->show_errors();

	// Check to see if the table is already in the database 
	// (the user has run the plugin before)
	if($wpdb->get_var("show tables like '$table_name'") != $table_name){
		// The code to create the table
		$sql = "CREATE TABLE ".$table_name. " (
				id int(9) NOT NULL AUTO_INCREMENT,
				PRIMARY KEY id (id)
				";
		
		// The special function 'dbDelta' we need below isn't 
		// included by default in WordPress
		require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
		// Special WordPress function to create table only if it 
		// doesn't already exist, or change the structure if it 
		// doesn't match the current one. This is useful if
		// we want to change the structure in the future
		dbDelta($sql);
		
		$welcome_text = "Congratulations, you just installed the DjVu Inegration plugin!";
		echo '<div class="updated"><p>'.$welcome_text.'</p></div>';
		/* Example code below
		$insert = "INSERT INTO ".$table_name.
			" (time,name,text) ".
			"VALUES ('".time()."','".$welcome_name."','".$welcome_text."')";
		
		$results = $wpdb->query( $insert );
		
		update_option('shoutbox_fade_from', "666666");
		update_option('shoutbox_fade_to', "FFFFFF");
		update_option('shoutbox_update_seconds', 4000);
		*/
		
	}
}

// Create the Wordpress template in the system, to be used
// when we create the pages
function di_add_template () {
	 // Copy the file djvu-page-sample.php to a new page theme
}


// For each DjVu file specified, create posts
function di_add_djvu_pages () {
  // Make sure to record which djvu document is first in the series
  // with the djvu_first_page option
	 
}

// Adds new posts for djvu directory with already existing metada
// about pages with same name. Delete old posts.
function di_reload_djvu_pages () {

}

// General function to display the data about the djvu page
// Basically, every page contains the following information about the djvu file:
//   + body of page:
//       + description of page (in excerpt field?)
// 	 + OCR text (if there is any)
//	 + category
//   + custom fields:
//     	 + name of djvu file (we don't need to store the path, because that's a global option)
//	 + keywords
// While viewing posts and logged in at a certain admin level,
// provide ability to edit metadata directly
function di_display_post () {

}

// Actions and Filters
add_action('admin_menu', 'di_admin_menu');	// insert the di_admin_menu() sink into the plugin hook
			 			// list for 'admin_menu'

// Add options to the Wordpress database; will only add, will not alter if these values already exist
add_option("djvu_dir", "wp-content/", "Directory of DjVu documents.", "yes");
add_option("djvu_txt_dir", "wp-content/", "Directory of OCR text for DjVu documents.", "yes");
add_option("djvu_image_dir", "wp-content/", "Directory of alternative images for the DjVu documents.", "yes");
add_option("djvu_pdf_dir", "wp-content/", "Directory of PDFs for the DjVu document.", "yes");
add_option("djvu_project_name", "", "Name of the DjVu project, to be displayed on the template.", "yes");
add_option("djvu_first_page", "", "page_id of the first page in the DjVu project.", "yes");

?>
